# ddmra

[![Latest Version](https://img.shields.io/pypi/v/ddmra.svg)](https://pypi.python.org/pypi/ddmra/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ddmra.svg)](https://pypi.python.org/pypi/ddmra/)
[![DOI](https://zenodo.org/badge/110845855.svg)](https://zenodo.org/badge/latestdoi/110845855)
[![License](https://img.shields.io/badge/License-LGPL%202.1-blue.svg)](https://opensource.org/licenses/LGPL-2.1)
[![CircleCI](https://circleci.com/gh/ME-ICA/ddmra.svg?style=shield)](https://circleci.com/gh/ME-ICA/ddmra)
[![Documentation Status](https://readthedocs.org/projects/ddmra/badge/?version=latest)](http://ddmra.readthedocs.io/en/latest/?badge=latest)
[![Codecov](https://codecov.io/gh/me-ica/ddmra/branch/main/graph/badge.svg)](https://codecov.io/gh/me-ica/ddmra)

Code for running distance-dependent motion-related artifact analyses in Python

We've chosen to model our DDMRA approach off of the analyses performed in
[Power et al. (2018)](https://doi.org/10.1073/pnas.1720985115), with some changes.

## Example results

<img src="docs/_static/example_results.png" alt="Example results" width="200"/>
